==> node-axios_0.21.4%2Bdfsg.orig.tar.xz: axios-0.21.4/test/specs/adapter.spec.js <==
var axios = require('../../index');

describe('adapter', function () {
  beforeEach(function () {
    jasmine.Ajax.install();
  });

  afterEach(function () {
    jasmine.Ajax.uninstall();
  });

  it('should support custom adapter', function (done) {
    axios('/foo', {
      adapter: function barAdapter(config) {
        return new Promise(function dispatchXhrRequest(resolve) {
          var request = new XMLHttpRequest();
          request.open('GET', '/bar');

          request.onreadystatechange = function () {
            resolve({
              config: config,
              request: request
            });
          };

          request.send(null);
        });
      }
    }).catch(console.log);

    getAjaxRequest().then(function(request) {
      expect(request.url).toBe('/bar');
      done();
    });
  });

  it('should execute adapter code synchronously', function (done) {
    var asyncFlag = false;
    axios('/foo', {
      adapter: function barAdapter(config) {
        return new Promise(function dispatchXhrRequest(resolve) {
          var request = new XMLHttpRequest();
          request.open('GET', '/bar');

          request.onreadystatechange = function () {
            resolve({
              config: config,
              request: request
            });
          };

          expect(asyncFlag).toBe(false);
          request.send(null);
        });
      }
    }).catch(console.log);

    asyncFlag = true;

    getAjaxRequest().then(function() {
      done();
    });
  });

  it('should execute adapter code asynchronously when interceptor is present', function (done) {
    var asyncFlag = false;

    axios.interceptors.request.use(function (config) {
      config.headers.async = 'async it!';
      return config;
    });

    axios('/foo', {
      adapter: function barAdapter(config) {
        return new Promise(function dispatchXhrRequest(resolve) {
          var request = new XMLHttpRequest();
          request.open('GET', '/bar');

          request.onreadystatechange = function () {
            resolve({
              config: config,
              request: request
            });
          };

          expect(asyncFlag).toBe(true);
          request.send(null);
        });
      }
    }).catch(console.log);

    asyncFlag = true;

    getAjaxRequest().then(function() {
      done();
    });
  });
});

==> node-axios_1.1.3%2Bdfsg.orig.tar.xz: axios-1.1.3/test/specs/adapter.spec.js <==

describe('adapter', function () {
  beforeEach(function () {
    jasmine.Ajax.install();
  });

  afterEach(function () {
    jasmine.Ajax.uninstall();
  });

  it('should support custom adapter', function (done) {
    axios('/foo', {
      adapter: function barAdapter(config) {
        return new Promise(function dispatchXhrRequest(resolve) {
          const request = new XMLHttpRequest();
          request.open('GET', '/bar');

          request.onreadystatechange = function () {
            resolve({
              config: config,
              request: request
            });
          };

          request.send(null);
        });
      }
    }).catch(done);

    getAjaxRequest().then(function(request) {
      expect(request.url).toBe('/bar');
      done();
    });
  });

  it('should execute adapter code synchronously', function (done) {
    let asyncFlag = false;
    axios('/foo', {
      adapter: function barAdapter(config) {
        return new Promise(function dispatchXhrRequest(resolve) {
          const request = new XMLHttpRequest();
          request.open('GET', '/bar');

          request.onreadystatechange = function () {
            resolve({
              config: config,
              request: request
            });
          };

          expect(asyncFlag).toBe(false);
          request.send(null);
        });
      }
    }).catch(done);

    asyncFlag = true;

    getAjaxRequest().then(function() {
      done();
    });
  });

  it('should execute adapter code asynchronously when interceptor is present', function (done) {
    let asyncFlag = false;

    axios.interceptors.request.use(function (config) {
      config.headers.async = 'async it!';
      return config;
    });

    axios('/foo', {
      adapter: function barAdapter(config) {
        return new Promise(function dispatchXhrRequest(resolve) {
          const request = new XMLHttpRequest();
          request.open('GET', '/bar');

          request.onreadystatechange = function () {
            resolve({
              config: config,
              request: request
            });
          };

          expect(asyncFlag).toBe(true);
          request.send(null);
        });
      }
    }).catch(done);

    asyncFlag = true;

    getAjaxRequest().then(function() {
      done();
    });
  });
});
